==> kvirc_3.2.0.orig.tar.gz: kvirc-3.2.0/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp <==
//=============================================================================
//
//   File : kvi_kvs_treenode_compositedata.cpp
//   Created on Tue 07 Oct 2003 02:24:33 by Szymon Stefanek
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 2003 Szymon Stefanek <pragma at kvirc dot net>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//=============================================================================

#define __KVIRC__

#include "kvi_kvs_treenode_compositedata.h"

#include "kvi_qstring.h"

#define DEBUGME

KviKvsTreeNodeCompositeData::KviKvsTreeNodeCompositeData(const QChar * pLocation,KviPtrList<KviKvsTreeNodeData> * pSubData)
: KviKvsTreeNodeData(pLocation)
{
#ifdef DEBUGME
	if(pSubData->count() < 2)debug("KviKvsTreeNodeCompositeData constructor called with less than two children!");
#endif
	m_pSubData = pSubData;
	m_pSubData->setAutoDelete(true);
	for(KviKvsTreeNodeData * d = m_pSubData->first();d;d = m_pSubData->next())
		d->setParent(this);
}


KviKvsTreeNodeCompositeData::~KviKvsTreeNodeCompositeData()
{
	delete m_pSubData;
}

bool KviKvsTreeNodeCompositeData::evaluateReadOnly(KviKvsRunTimeContext * c,KviKvsVariant * pBuffer)
{
	QString * pS = new QString();

	pBuffer->setString(pS);
	
	KviKvsVariant res;
	for(KviKvsTreeNodeData * d = m_pSubData->first();d;d = m_pSubData->next())
	{
		if(!d->evaluateReadOnly(c,&res))return false;
		res.appendAsString(*pS);
	}
	return true;
}

void KviKvsTreeNodeCompositeData::dump(const char * prefix)
{
	debug("%s CompositeData",prefix);
	QString tmp = prefix;
	tmp.append("  ");
	for(KviKvsTreeNodeData * p = m_pSubData->first();p;p = m_pSubData->next())
	{
		p->dump(tmp.latin1());
	}
}

==> kvirc_3.2.4.orig.tar.gz: kvirc-3.2.4/src/kvirc/kvs/kvi_kvs_treenode_compositedata.cpp <==
//=============================================================================
//
//   File : kvi_kvs_treenode_compositedata.cpp
//   Created on Tue 07 Oct 2003 02:24:33 by Szymon Stefanek
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 2003 Szymon Stefanek <pragma at kvirc dot net>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//=============================================================================

#define __KVIRC__

#include "kvi_kvs_treenode_compositedata.h"

#include "kvi_qstring.h"

#define DEBUGME

KviKvsTreeNodeCompositeData::KviKvsTreeNodeCompositeData(const QChar * pLocation,KviPtrList<KviKvsTreeNodeData> * pSubData)
: KviKvsTreeNodeData(pLocation)
{
#ifdef DEBUGME
	if(pSubData->count() < 2)debug("KviKvsTreeNodeCompositeData constructor called with less than two children!");
#endif
	m_pSubData = pSubData;
	m_pSubData->setAutoDelete(true);
	for(KviKvsTreeNodeData * d = m_pSubData->first();d;d = m_pSubData->next())
		d->setParent(this);
}


KviKvsTreeNodeCompositeData::~KviKvsTreeNodeCompositeData()
{
	delete m_pSubData;
}

bool KviKvsTreeNodeCompositeData::evaluateReadOnly(KviKvsRunTimeContext * c,KviKvsVariant * pBuffer)
{
	QString * pS = new QString();

	pBuffer->setString(pS);
	
	KviKvsVariant res;

	// we need to use an iterator to accomodate recursion
	KviPtrListIterator<KviKvsTreeNodeData> it(*m_pSubData);
	
	while(KviKvsTreeNodeData * d = it.current())
	{
		if(!d->evaluateReadOnly(c,&res))return false;
		res.appendAsString(*pS);
		++it;
	}
	return true;
}

void KviKvsTreeNodeCompositeData::contextDescription(QString &szBuffer)
{
	szBuffer = "Composite Data Evaluation (Implicit String Cast)";
}

void KviKvsTreeNodeCompositeData::dump(const char * prefix)
{
	debug("%s CompositeData",prefix);
	QString tmp = prefix;
	tmp.append("  ");
	for(KviKvsTreeNodeData * p = m_pSubData->first();p;p = m_pSubData->next())
	{
		p->dump(tmp.utf8().data());
	}
}
